@@ -1,6 +1,6 @@
 package Mason::Plugin::Cache::Interp;
 BEGIN {
-  $Mason::Plugin::Cache::Interp::VERSION = '0.02';
+  $Mason::Plugin::Cache::Interp::VERSION = '0.03';
 }
 use CHI;
 use Mason::Util qw(catdir);
@@ -8,8 +8,8 @@ use Mason::PluginRole;
 
 # Passed attributes
 #
-has 'cache_defaults'   => ( isa => 'HashRef', lazy_build => 1 );
-has 'cache_root_class' => ( isa => 'Str', default => 'CHI' );
+has 'cache_defaults'   => ( is => 'ro', isa => 'HashRef', lazy_build => 1 );
+has 'cache_root_class' => ( is => 'ro', isa => 'Str', default => 'CHI' );
 
 method _build_cache_defaults () {
     return {
